@@ -10,7 +10,7 @@ sub title { 'フレパのあなたの日記へのコメント' }
 sub start_url { 'http://www.frepa.livedoor.com/blog/recent_comment' }
 
 sub get_list {
-    my ($self, $mech) = @_;
+    my($self, $mech, $plugin) = @_;
 
     my @msgs = ();
     $mech->get($self->start_url);
@@ -22,10 +22,14 @@ sub get_list {
         my $time = "$1/$2/$3 $4:$5";
         my ($link, $subject, $user_link, $name) =
             (decode_entities($6), decode_entities($7), decode_entities($8), decode_entities($9));
-        my $uri = URI->new($self->start_url);
-        $uri->path($link);
+        my $uri = URI->new_abs($link, $self->start_url);
         $link = $uri->as_string;
 
+        # your post doesn't link to your profile, ick
+        if ($user_link =~ m!www\.frepa\.livedoor\.com/$!) {
+            $user_link = "http://frepa.livedoor.com/" . $plugin->conf->{livedoor_id} . "/";
+        }
+
         push(@msgs, +{
             user_link => $user_link,
             link      => $link,
