@@ -1,7 +1,7 @@
 package Plagger::Util;
 use strict;
 our @ISA = qw(Exporter);
-our @EXPORT_OK = qw( strip_html dumbnail decode_content extract_title load_uri mime_type_of filename_for );
+our @EXPORT_OK = qw( strip_html dumbnail decode_content extract_title load_uri mime_type_of filename_for mime_is_enclosure );
 
 use Encode ();
 use List::Util qw(min);
@@ -132,19 +132,26 @@ sub load_uri {
 
 our $mimetypes = MIME::Types->new;
 $mimetypes->addType( MIME::Type->new(type => 'video/x-flv', extensions => [ 'flv' ]) );
-$mimetypes->addType( MIME::Type->new(type => 'audio/aac', extensions => [ 'm4a', '.aac' ]) );
+$mimetypes->addType( MIME::Type->new(type => 'audio/aac', extensions => [ 'm4a', 'aac' ]) );
+$mimetypes->addType( MIME::Type->new(type => 'video/mp4', extensions => [ 'mp4', 'm4v' ]) );
 
 sub mime_type_of {
     my $ext = shift;
 
     if (UNIVERSAL::isa($ext, 'URI')) {
-        $ext = ( $ext->path =~ /\.(\w+)/ )[0];
+        $ext = ( $ext->path =~ /\.(\w+)$/ )[0];
     }
 
     return unless $ext;
     return $mimetypes->mimeTypeOf($ext);
 }
 
+sub mime_is_enclosure {
+    my $mime = shift;
+    return unless $mime;
+    $mime->mediaType =~ m!^(?:audio|video|image)$! || $mime->type eq 'application/ogg';
+}
+
 my %entities = (
     '&' => '&amp;',
     '<' => '&lt;',
